---
name: Feature request
about: For new things and improvements that are not bugs.
title: ''
labels: feature
assignees: ''

---

**Describe the feature**
A clear and concise description of what feature you're requesting.

**Motivation**
Why would you like to have this feature in the SDK. How would you use it? How would it help you?

**Constraints**
Are there any requirements or limits to the feature that need to be satisfied?
